Documentation
¶
Index ¶
- Variables
- type CPU
- type Command
- type Commands
- type DetectPoint
- func (DetectPoint) Descriptor() protoreflect.EnumDescriptor
- func (x DetectPoint) Enum() *DetectPoint
- func (DetectPoint) EnumDescriptor() ([]byte, []int)deprecated
- func (x DetectPoint) Number() protoreflect.EnumNumber
- func (x DetectPoint) String() string
- func (DetectPoint) Type() protoreflect.EnumType
- type Instant
- type KeyIntValuePair
- func (*KeyIntValuePair) Descriptor() ([]byte, []int)deprecated
- func (x *KeyIntValuePair) GetKey() string
- func (x *KeyIntValuePair) GetValue() int64
- func (*KeyIntValuePair) ProtoMessage()
- func (x *KeyIntValuePair) ProtoReflect() protoreflect.Message
- func (x *KeyIntValuePair) Reset()
- func (x *KeyIntValuePair) String() string
- type KeyStringValuePair
- func (*KeyStringValuePair) Descriptor() ([]byte, []int)deprecated
- func (x *KeyStringValuePair) GetKey() string
- func (x *KeyStringValuePair) GetValue() string
- func (*KeyStringValuePair) ProtoMessage()
- func (x *KeyStringValuePair) ProtoReflect() protoreflect.Message
- func (x *KeyStringValuePair) Reset()
- func (x *KeyStringValuePair) String() string
Constants ¶
This section is empty.
Variables ¶
var ( DetectPoint_name = map[int32]string{ 0: "client", 1: "server", 2: "proxy", } DetectPoint_value = map[string]int32{ "client": 0, "server": 1, "proxy": 2, } )
Enum value maps for DetectPoint.
var File_common_Command_proto protoreflect.FileDescriptor
var File_common_Common_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CPU ¶
type CPU struct {
UsagePercent float64 `protobuf:"fixed64,2,opt,name=usagePercent,proto3" json:"usagePercent,omitempty"`
// contains filtered or unexported fields
}
func (*CPU) Descriptor
deprecated
func (*CPU) GetUsagePercent ¶
func (*CPU) ProtoMessage ¶
func (*CPU) ProtoMessage()
func (*CPU) ProtoReflect ¶
func (x *CPU) ProtoReflect() protoreflect.Message
type Command ¶
type Command struct {
// Use command name to distinguish different data type.
Command string `protobuf:"bytes,1,opt,name=command,proto3" json:"command,omitempty"`
// Data content in command.
// The value of content needs to be serialized as string for transmission.
//
// Basic data type: convert as string.
// The list of basic data: multiple data are split by ",".
// Complex data: serialize string through json.
Args []*KeyStringValuePair `protobuf:"bytes,2,rep,name=args,proto3" json:"args,omitempty"`
// contains filtered or unexported fields
}
Command represents an protocol customized data when return.
When the agent communicates with the OAP side using gRPC, the OAP uses Command to return the data content to the Agent.
The available commands are, Name: ConfigurationDiscoveryCommand Args:
SerialNumber: String UUID: String properties: Key-value pairs rely on agent-side implementations
Ref, Java agent supported configurations, https://skywalking.apache.org/docs/skywalking-java/next/en/setup/service-agent/java-agent/configuration-discovery/
Name: ProfileTaskQuery Args:
SerialNumber: String TaskId: String EndpointName: String Duration: Integer MinDurationThreshold: Integer DumpPeriod: Integer MaxSamplingCount: Integer StartTime: Date Timestamp CreateTime: Date Timestamp
Name: EBPFProfilingTaskQuery Args:
TaskId: String
ProcessId: Integer List
TaskUpdateTime: Date timestamp
TriggerType: Enum, value = FIXED_TIME
TargetType: Enum, value = ON_CPU, OFF_CPU or NETWORK
TaskStartTime: Date Timestamp
ExtensionConfigJSON: JSON serialization of NetworkSamplings.
--- NetworkSamplings ---
NetworkSamplings: List
URIRegex: String
MinDuration: Integer
When4xx: Boolean
When5xx: Boolean
Settings: Object
RequireCompleteRequest: Boolean
MaxRequestSize: Integer
RequireCompleteResponse: Boolean
MaxResponseSize: Integer
------------------------
FixedTriggerDuration: Long
Name: ContinuousProfilingPolicyQuery Args:
ServiceWithPolicyJSON: List JSON serialization of ServiceWithPolicy.
--- ServiceWithPolicy ---
ServiceName: String
UUID: String
Profiling: Multiple profiling configuration. Map
Key: Profiling type. Enum, value = ON_CPU, OFF_CPU, NETWORK
Value: Profiling policies. Map
Key: Monitoring type. Enum, value = PROCESS_CPU, PROCESS_THREAD_COUNT, SYSTEM_LOAD, HTTP_ERROR_RATE, HTTP_AVG_RESPONSE_TIME
Value: Policy configuration. Object.
Threshold: String
Period(s): Integer
Count: Integer
URIList: List<String>
URIRegex: String
---------------------------
Name: ContinuousProfilingReportTask Args:
TaskId: String
func (*Command) Descriptor
deprecated
func (*Command) GetArgs ¶
func (x *Command) GetArgs() []*KeyStringValuePair
func (*Command) GetCommand ¶
func (*Command) ProtoMessage ¶
func (*Command) ProtoMessage()
func (*Command) ProtoReflect ¶
func (x *Command) ProtoReflect() protoreflect.Message
type Commands ¶
type Commands struct {
Commands []*Command `protobuf:"bytes,1,rep,name=commands,proto3" json:"commands,omitempty"`
// contains filtered or unexported fields
}
Transferring multiple Command in agent and OAP.
func (*Commands) Descriptor
deprecated
func (*Commands) GetCommands ¶
func (*Commands) ProtoMessage ¶
func (*Commands) ProtoMessage()
func (*Commands) ProtoReflect ¶
func (x *Commands) ProtoReflect() protoreflect.Message
type DetectPoint ¶
type DetectPoint int32
In most cases, detect point should be `server` or `client`. Even in service mesh, this means `server`/`client` side sidecar `proxy` is reserved only.
const ( DetectPoint_client DetectPoint = 0 DetectPoint_server DetectPoint = 1 DetectPoint_proxy DetectPoint = 2 )
func (DetectPoint) Descriptor ¶
func (DetectPoint) Descriptor() protoreflect.EnumDescriptor
func (DetectPoint) Enum ¶
func (x DetectPoint) Enum() *DetectPoint
func (DetectPoint) EnumDescriptor
deprecated
func (DetectPoint) EnumDescriptor() ([]byte, []int)
Deprecated: Use DetectPoint.Descriptor instead.
func (DetectPoint) Number ¶
func (x DetectPoint) Number() protoreflect.EnumNumber
func (DetectPoint) String ¶
func (x DetectPoint) String() string
func (DetectPoint) Type ¶
func (DetectPoint) Type() protoreflect.EnumType
type Instant ¶
type Instant struct {
// The number of seconds from the epoch of 1970-01-01T00:00:00Z.
Seconds int64 `protobuf:"varint,1,opt,name=seconds,proto3" json:"seconds,omitempty"`
// The number of nanoseconds, later along the time-line, from the seconds field.
// This is always positive, and never exceeds 999,999,999.
Nanos int32 `protobuf:"varint,2,opt,name=nanos,proto3" json:"nanos,omitempty"`
// contains filtered or unexported fields
}
since v3.1 An instantaneous point on the time-line. An instant represents a data point accurate to the nanosecond. It is constituted by a long representing epoch-seconds and an int representing nanosecond-of-second, which will always be between 0 and 999,999,999
func (*Instant) Descriptor
deprecated
func (*Instant) GetSeconds ¶
func (*Instant) ProtoMessage ¶
func (*Instant) ProtoMessage()
func (*Instant) ProtoReflect ¶
func (x *Instant) ProtoReflect() protoreflect.Message
type KeyIntValuePair ¶
type KeyIntValuePair struct {
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
Value int64 `protobuf:"varint,2,opt,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
since v3.1 An extension of KeyStringValuePair represents a kind of metric value for the key.
func (*KeyIntValuePair) Descriptor
deprecated
func (*KeyIntValuePair) Descriptor() ([]byte, []int)
Deprecated: Use KeyIntValuePair.ProtoReflect.Descriptor instead.
func (*KeyIntValuePair) GetKey ¶
func (x *KeyIntValuePair) GetKey() string
func (*KeyIntValuePair) GetValue ¶
func (x *KeyIntValuePair) GetValue() int64
func (*KeyIntValuePair) ProtoMessage ¶
func (*KeyIntValuePair) ProtoMessage()
func (*KeyIntValuePair) ProtoReflect ¶
func (x *KeyIntValuePair) ProtoReflect() protoreflect.Message
func (*KeyIntValuePair) Reset ¶
func (x *KeyIntValuePair) Reset()
func (*KeyIntValuePair) String ¶
func (x *KeyIntValuePair) String() string
type KeyStringValuePair ¶
type KeyStringValuePair struct {
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
Value string `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
func (*KeyStringValuePair) Descriptor
deprecated
func (*KeyStringValuePair) Descriptor() ([]byte, []int)
Deprecated: Use KeyStringValuePair.ProtoReflect.Descriptor instead.
func (*KeyStringValuePair) GetKey ¶
func (x *KeyStringValuePair) GetKey() string
func (*KeyStringValuePair) GetValue ¶
func (x *KeyStringValuePair) GetValue() string
func (*KeyStringValuePair) ProtoMessage ¶
func (*KeyStringValuePair) ProtoMessage()
func (*KeyStringValuePair) ProtoReflect ¶
func (x *KeyStringValuePair) ProtoReflect() protoreflect.Message
func (*KeyStringValuePair) Reset ¶
func (x *KeyStringValuePair) Reset()
func (*KeyStringValuePair) String ¶
func (x *KeyStringValuePair) String() string